==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/mps/v20190612/models/AiAnalysisTaskFrameTagOutput.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mps.v20190612.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AiAnalysisTaskFrameTagOutput extends AbstractModel{

    /**
    * 视频按帧标签列表。
    */
    @SerializedName("SegmentSet")
    @Expose
    private MediaAiAnalysisFrameTagSegmentItem [] SegmentSet;

    /**
     * Get 视频按帧标签列表。 
     * @return SegmentSet 视频按帧标签列表。
     */
    public MediaAiAnalysisFrameTagSegmentItem [] getSegmentSet() {
        return this.SegmentSet;
    }

    /**
     * Set 视频按帧标签列表。
     * @param SegmentSet 视频按帧标签列表。
     */
    public void setSegmentSet(MediaAiAnalysisFrameTagSegmentItem [] SegmentSet) {
        this.SegmentSet = SegmentSet;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "SegmentSet.", this.SegmentSet);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/mps/v20190612/models/AiAnalysisTaskFrameTagOutput.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mps.v20190612.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AiAnalysisTaskFrameTagOutput extends AbstractModel{

    /**
    * 视频按帧标签列表。
    */
    @SerializedName("SegmentSet")
    @Expose
    private MediaAiAnalysisFrameTagSegmentItem [] SegmentSet;

    /**
     * Get 视频按帧标签列表。 
     * @return SegmentSet 视频按帧标签列表。
     */
    public MediaAiAnalysisFrameTagSegmentItem [] getSegmentSet() {
        return this.SegmentSet;
    }

    /**
     * Set 视频按帧标签列表。
     * @param SegmentSet 视频按帧标签列表。
     */
    public void setSegmentSet(MediaAiAnalysisFrameTagSegmentItem [] SegmentSet) {
        this.SegmentSet = SegmentSet;
    }

    public AiAnalysisTaskFrameTagOutput() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AiAnalysisTaskFrameTagOutput(AiAnalysisTaskFrameTagOutput source) {
        if (source.SegmentSet != null) {
            this.SegmentSet = new MediaAiAnalysisFrameTagSegmentItem[source.SegmentSet.length];
            for (int i = 0; i < source.SegmentSet.length; i++) {
                this.SegmentSet[i] = new MediaAiAnalysisFrameTagSegmentItem(source.SegmentSet[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "SegmentSet.", this.SegmentSet);

    }
}
